@@ -39,6 +39,8 @@ static long            GMPy_Integer_AsLongWithType(PyObject *x, int xtype);
 static long            GMPy_Integer_AsLong(PyObject *x);
 static unsigned long   GMPy_Integer_AsUnsignedLongWithType(PyObject *x, int xtype);
 static unsigned long   GMPy_Integer_AsUnsignedLong(PyObject *x);
+static unsigned long   GMPy_Integer_AsUnsignedLongWithType_v2(PyObject *x, int xtype);
+static unsigned long   GMPy_Integer_AsUnsignedLong_v2(PyObject *x);
 
 #ifdef _WIN64
 static PY_LONG_LONG          GMPy_Integer_AsLongLongWithType(PyObject *x, int xtype);
