@@ -6,7 +6,7 @@
  *                                                                         *
  * Copyright 2011 David Cleaver                                            *
  *                                                                         *
- * Copyright 2012, 2013, 2014, 2015 Case Van Horsen                        *
+ * Copyright 2012 - 2022 Case Van Horsen                                   *
  *                                                                         *
  * The original file is available at:                                      *
  *   <http://sourceforge.net/projects/mpzlucas/files/>                     *
@@ -42,7 +42,7 @@ GMPY_mpz_lucasu(PyObject *self, PyObject *args)
      * Note: p^2-4q=0 is not tested, not a proper Lucas sequence!!
      */
 
-    PympzObject *result = 0, *p, *q, *k;
+    MPZ_Object *result = NULL, *p = NULL, *q = NULL, *k = NULL;
     size_t s = 0, j = 0;
     mpz_t uh, vl, vh, ql, qh, tmp;
 
@@ -51,19 +51,16 @@ GMPY_mpz_lucasu(PyObject *self, PyObject *args)
         return NULL;
     }
 
-    /* Take advantage of the cache of mpz_t objects maintained by GMPY2 to
-     * avoid memory allocations. */
+    mpz_init(uh);
+    mpz_init(vl);
+    mpz_init(vh);
+    mpz_init(ql);
+    mpz_init(qh);
+    mpz_init(tmp);
 
-    mpz_inoc(uh);
-    mpz_inoc(vl);
-    mpz_inoc(vh);
-    mpz_inoc(ql);
-    mpz_inoc(qh);
-    mpz_inoc(tmp);
-
-    p = Pympz_From_Integer(PyTuple_GET_ITEM(args, 0));
-    q = Pympz_From_Integer(PyTuple_GET_ITEM(args, 1));
-    k = Pympz_From_Integer(PyTuple_GET_ITEM(args, 2));
+    p = GMPy_MPZ_From_Integer(PyTuple_GET_ITEM(args, 0), NULL);
+    q = GMPy_MPZ_From_Integer(PyTuple_GET_ITEM(args, 1), NULL);
+    k = GMPy_MPZ_From_Integer(PyTuple_GET_ITEM(args, 2), NULL);
     if (!p || !q || !k) {
         TYPE_ERROR("lucasu() requires 3 integer arguments");
         goto cleanup;
@@ -164,19 +161,19 @@ GMPY_mpz_lucasu(PyObject *self, PyObject *args)
         mpz_mul(ql, ql, ql);
     }
 
-    if (!(result = (PympzObject*)Pympz_new()))
+    if (!(result = GMPy_MPZ_New(NULL)))
         goto cleanup;
 
     /* uh contains our return value */
     mpz_set(result->z, uh);
 
   cleanup:
-    mpz_cloc(uh);
-    mpz_cloc(vl);
-    mpz_cloc(vh);
-    mpz_cloc(ql);
-    mpz_cloc(qh);
-    mpz_cloc(tmp);
+    mpz_clear(uh);
+    mpz_clear(vl);
+    mpz_clear(vh);
+    mpz_clear(ql);
+    mpz_clear(qh);
+    mpz_clear(tmp);
     Py_XDECREF((PyObject*)p);
     Py_XDECREF((PyObject*)q);
     Py_XDECREF((PyObject*)k);
@@ -198,7 +195,7 @@ GMPY_mpz_lucasu_mod(PyObject *self, PyObject *args)
      * Note: p^2-4q=0 is not tested, not a proper Lucas sequence!!
      */
 
-    PympzObject *result = 0, *p, *q, *k, *n;
+    MPZ_Object *result = NULL, *p = NULL, *q = NULL, *k = NULL, *n = NULL;
 
     size_t s = 0, j = 0;
     mpz_t uh, vl, vh, ql, qh, tmp;
@@ -208,20 +205,17 @@ GMPY_mpz_lucasu_mod(PyObject *self, PyObject *args)
         return NULL;
     }
 
-    /* Take advantage of the cache of mpz_t objects maintained by GMPY2 to
-     * avoid memory allocations. */
+    mpz_init(uh);
+    mpz_init(vl);
+    mpz_init(vh);
+    mpz_init(ql);
+    mpz_init(qh);
+    mpz_init(tmp);
 
-    mpz_inoc(uh);
-    mpz_inoc(vl);
-    mpz_inoc(vh);
-    mpz_inoc(ql);
-    mpz_inoc(qh);
-    mpz_inoc(tmp);
-
-    p = Pympz_From_Integer(PyTuple_GET_ITEM(args, 0));
-    q = Pympz_From_Integer(PyTuple_GET_ITEM(args, 1));
-    k = Pympz_From_Integer(PyTuple_GET_ITEM(args, 2));
-    n = Pympz_From_Integer(PyTuple_GET_ITEM(args, 3));
+    p = GMPy_MPZ_From_Integer(PyTuple_GET_ITEM(args, 0), NULL);
+    q = GMPy_MPZ_From_Integer(PyTuple_GET_ITEM(args, 1), NULL);
+    k = GMPy_MPZ_From_Integer(PyTuple_GET_ITEM(args, 2), NULL);
+    n = GMPy_MPZ_From_Integer(PyTuple_GET_ITEM(args, 3), NULL);
     if (!p || !q || !k || !n) {
         TYPE_ERROR("lucasu_mod() requires 4 integer arguments");
         goto cleanup;
@@ -339,19 +333,19 @@ GMPY_mpz_lucasu_mod(PyObject *self, PyObject *args)
         mpz_mod(ql, ql, n->z);
     }
 
-    if (!(result = (PympzObject*)Pympz_new()))
+    if (!(result = GMPy_MPZ_New(NULL)))
         goto cleanup;
 
     /* uh contains our return value */
     mpz_mod(result->z, uh, n->z);
 
   cleanup:
-    mpz_cloc(uh);
-    mpz_cloc(vl);
-    mpz_cloc(vh);
-    mpz_cloc(ql);
-    mpz_cloc(qh);
-    mpz_cloc(tmp);
+    mpz_clear(uh);
+    mpz_clear(vl);
+    mpz_clear(vh);
+    mpz_clear(ql);
+    mpz_clear(qh);
+    mpz_clear(tmp);
     Py_XDECREF((PyObject*)p);
     Py_XDECREF((PyObject*)q);
     Py_XDECREF((PyObject*)k);
@@ -373,7 +367,7 @@ GMPY_mpz_lucasv(PyObject *self, PyObject *args)
      * Note: p^2-4q=0 is not tested, not a proper Lucas sequence!!
      */
 
-    PympzObject *result = 0, *p, *q, *k;
+    MPZ_Object *result = NULL, *p = NULL, *q = NULL, *k = NULL;
     size_t s = 0, j = 0;
     mpz_t vl, vh, ql, qh, tmp;
 
@@ -382,18 +376,15 @@ GMPY_mpz_lucasv(PyObject *self, PyObject *args)
         return NULL;
     }
 
-    /* Take advantage of the cache of mpz_t objects maintained by GMPY2 to
-     * avoid memory allocations. */
+    mpz_init(vl);
+    mpz_init(vh);
+    mpz_init(ql);
+    mpz_init(qh);
+    mpz_init(tmp);
 
-    mpz_inoc(vl);
-    mpz_inoc(vh);
-    mpz_inoc(ql);
-    mpz_inoc(qh);
-    mpz_inoc(tmp);
-
-    p = Pympz_From_Integer(PyTuple_GET_ITEM(args, 0));
-    q = Pympz_From_Integer(PyTuple_GET_ITEM(args, 1));
-    k = Pympz_From_Integer(PyTuple_GET_ITEM(args, 2));
+    p = GMPy_MPZ_From_Integer(PyTuple_GET_ITEM(args, 0), NULL);
+    q = GMPy_MPZ_From_Integer(PyTuple_GET_ITEM(args, 1), NULL);
+    k = GMPy_MPZ_From_Integer(PyTuple_GET_ITEM(args, 2), NULL);
     if (!p || !q || !k) {
         TYPE_ERROR("lucasv() requires 3 integer arguments");
         goto cleanup;
@@ -479,18 +470,18 @@ GMPY_mpz_lucasv(PyObject *self, PyObject *args)
         mpz_mul(ql, ql, ql);
     }
 
-    if (!(result = (PympzObject*)Pympz_new()))
+    if (!(result = GMPy_MPZ_New(NULL)))
         goto cleanup;
 
     /* vl contains our return value */
     mpz_set(result->z, vl);
 
   cleanup:
-    mpz_cloc(vl);
-    mpz_cloc(vh);
-    mpz_cloc(ql);
-    mpz_cloc(qh);
-    mpz_cloc(tmp);
+    mpz_clear(vl);
+    mpz_clear(vh);
+    mpz_clear(ql);
+    mpz_clear(qh);
+    mpz_clear(tmp);
     Py_XDECREF((PyObject*)p);
     Py_XDECREF((PyObject*)q);
     Py_XDECREF((PyObject*)k);
@@ -512,7 +503,7 @@ GMPY_mpz_lucasv_mod(PyObject *self, PyObject *args)
      * Note: p^2-4q=0 is not tested, not a proper Lucas sequence!!
      */
 
-    PympzObject *result = 0, *p, *q, *k, *n;
+    MPZ_Object *result = NULL, *p = NULL, *q = NULL, *k = NULL, *n = NULL;
 
     size_t s = 0, j = 0;
     mpz_t vl, vh, ql, qh, tmp;
@@ -522,19 +513,16 @@ GMPY_mpz_lucasv_mod(PyObject *self, PyObject *args)
         return NULL;
     }
 
-    /* Take advantage of the cache of mpz_t objects maintained by GMPY2 to
-     * avoid memory allocations. */
+    mpz_init(vl);
+    mpz_init(vh);
+    mpz_init(ql);
+    mpz_init(qh);
+    mpz_init(tmp);
 
-    mpz_inoc(vl);
-    mpz_inoc(vh);
-    mpz_inoc(ql);
-    mpz_inoc(qh);
-    mpz_inoc(tmp);
-
-    p = Pympz_From_Integer(PyTuple_GET_ITEM(args, 0));
-    q = Pympz_From_Integer(PyTuple_GET_ITEM(args, 1));
-    k = Pympz_From_Integer(PyTuple_GET_ITEM(args, 2));
-    n = Pympz_From_Integer(PyTuple_GET_ITEM(args, 3));
+    p = GMPy_MPZ_From_Integer(PyTuple_GET_ITEM(args, 0), NULL);
+    q = GMPy_MPZ_From_Integer(PyTuple_GET_ITEM(args, 1), NULL);
+    k = GMPy_MPZ_From_Integer(PyTuple_GET_ITEM(args, 2), NULL);
+    n = GMPy_MPZ_From_Integer(PyTuple_GET_ITEM(args, 3), NULL);
     if (!p || !q || !k || !n) {
         TYPE_ERROR("lucasv_mod() requires 4 integer arguments");
         goto cleanup;
@@ -634,18 +622,18 @@ GMPY_mpz_lucasv_mod(PyObject *self, PyObject *args)
         mpz_mod(ql, ql, n->z);
     }
 
-    if (!(result = (PympzObject*)Pympz_new()))
+    if (!(result = GMPy_MPZ_New(NULL)))
         goto cleanup;
 
     /* vl contains our return value */
     mpz_mod(result->z, vl, n->z);
 
   cleanup:
-    mpz_cloc(vl);
-    mpz_cloc(vh);
-    mpz_cloc(ql);
-    mpz_cloc(qh);
-    mpz_cloc(tmp);
+    mpz_clear(vl);
+    mpz_clear(vh);
+    mpz_clear(ql);
+    mpz_clear(qh);
+    mpz_clear(tmp);
     Py_XDECREF((PyObject*)p);
     Py_XDECREF((PyObject*)q);
     Py_XDECREF((PyObject*)k);
